@@ -549,17 +549,49 @@ impl<T: Num + Copy> Mul<T> for M55<T> {
 
 
 // M55 * V5
-impl<T: Num + Copy + std::iter::Sum> Mul<V5<T>> for M55<T> {
+impl<T: Num + Copy> Mul<V5<T>> for M55<T> {
     type Output = V5<T>;
 
     fn mul(self, rhs: V5<T>) -> V5<T> {
 
-        let rows = self.get_rows();
-        let v0 = dot(&*rows[0], &*rhs);
-        let v1 = dot(&*rows[1], &*rhs);
-        let v2 = dot(&*rows[2], &*rhs);
-        let v3 = dot(&*rows[3], &*rhs);
-        let v4 = dot(&*rows[4], &*rhs);
+        let a_00 = self[(0, 0)];
+        let a_01 = self[(0, 1)];
+        let a_02 = self[(0, 2)];
+        let a_03 = self[(0, 3)];
+        let a_04 = self[(0, 4)];
+        let a_10 = self[(1, 0)];
+        let a_11 = self[(1, 1)];
+        let a_12 = self[(1, 2)];
+        let a_13 = self[(1, 3)];
+        let a_14 = self[(1, 4)];
+        let a_20 = self[(2, 0)];
+        let a_21 = self[(2, 1)];
+        let a_22 = self[(2, 2)];
+        let a_23 = self[(2, 3)];
+        let a_24 = self[(2, 4)];
+        let a_30 = self[(3, 0)];
+        let a_31 = self[(3, 1)];
+        let a_32 = self[(3, 2)];
+        let a_33 = self[(3, 3)];
+        let a_34 = self[(3, 4)];
+        let a_40 = self[(4, 0)];
+        let a_41 = self[(4, 1)];
+        let a_42 = self[(4, 2)];
+        let a_43 = self[(4, 3)];
+        let a_44 = self[(4, 4)];
+
+        let a = rhs[0];
+        let b = rhs[1];
+        let c = rhs[2];
+        let d = rhs[3];
+        let e = rhs[4];
+
+        let v0 = a_00 * a + a_01 * b + a_02 * c + a_03 * d + a_04 * e;
+        let v1 = a_10 * a + a_11 * b + a_12 * c + a_13 * d + a_14 * e;
+        let v2 = a_20 * a + a_21 * b + a_22 * c + a_23 * d + a_24 * e;
+        let v3 = a_30 * a + a_31 * b + a_32 * c + a_33 * d + a_34 * e;
+        let v4 = a_40 * a + a_41 * b + a_42 * c + a_43 * d + a_44 * e;
+
         V5::new([v0, v1, v2, v3, v4])
     }
 
