@@ -32,7 +32,7 @@ use std::fmt;
 use num::{Float, Zero, Num};
 use std::ops::{Deref, DerefMut};
 
-use std::ops::{Add, Mul, Sub};
+use std::ops::{Add, Mul, Sub, SubAssign, AddAssign};
 
 use crate::errors::VectorErrors;
 use crate::matrix2x2::*;
@@ -165,6 +165,13 @@ impl<T: Num + Copy> Sub for V2<T> {
     }
 }
 
+// V2 -= V2
+impl<T: Num + Copy> SubAssign for V2<T> {
+    fn sub_assign(&mut self, other: Self) {
+        *self = *self - other
+    }
+}
+
 // V2 + V2
 impl<T: Num + Copy> Add for V2<T> {
     type Output = Self;
@@ -180,6 +187,13 @@ impl<T: Num + Copy> Add for V2<T> {
     }
 }
 
+// V2 += V2
+impl<T: Num + Copy> AddAssign for V2<T> {
+    fn add_assign(&mut self, other: Self) {
+        *self = *self + other
+    }
+}
+
 // Zero trait
 impl<T: Num + Copy> Zero for V2<T> {
     fn zero() -> V2<T> {
@@ -339,4 +353,34 @@ mod vector2_test {
             &expected[..]
         );
     }
+
+    #[test]
+    fn sub_assigment_test() {
+        let mut result = V2::new([1.0, 3.0]);
+        let v2 = V2::new([3.0, 3.0]);
+        let expected = V2::new([-2.0, 0.0]);
+        result -= v2;
+        assert_eq!(
+            &result[..],
+            &expected[..],
+            "\nExpected\n{:?}\nfound\n{:?}",
+            &result[..],
+            &expected[..]
+        );
+    }
+
+    #[test]
+    fn add_assigment_test() {
+        let mut result = V2::new([1.0, 3.0]);
+        let v2 = V2::new([3.0, 3.0]);
+        let expected = V2::new([4.0, 6.0]);
+        result += v2;
+        assert_eq!(
+            &result[..],
+            &expected[..],
+            "\nExpected\n{:?}\nfound\n{:?}",
+            &result[..],
+            &expected[..]
+        );
+    }
 }
